[−][src]Enum unicode_types::box_drawing::BoxDrawing
An enum to represent all characters in the BoxDrawing block.
Variants
LightHorizontal\u{2500}: '─'
HeavyHorizontal\u{2501}: '━'
LightVertical\u{2502}: '│'
HeavyVertical\u{2503}: '┃'
LightTripleDashHorizontal\u{2504}: '┄'
HeavyTripleDashHorizontal\u{2505}: '┅'
LightTripleDashVertical\u{2506}: '┆'
HeavyTripleDashVertical\u{2507}: '┇'
LightQuadrupleDashHorizontal\u{2508}: '┈'
HeavyQuadrupleDashHorizontal\u{2509}: '┉'
LightQuadrupleDashVertical\u{250a}: '┊'
HeavyQuadrupleDashVertical\u{250b}: '┋'
LightDownAndRight\u{250c}: '┌'
DownLightAndRightHeavy\u{250d}: '┍'
DownHeavyAndRightLight\u{250e}: '┎'
HeavyDownAndRight\u{250f}: '┏'
LightDownAndLeft\u{2510}: '┐'
DownLightAndLeftHeavy\u{2511}: '┑'
DownHeavyAndLeftLight\u{2512}: '┒'
HeavyDownAndLeft\u{2513}: '┓'
LightUpAndRight\u{2514}: '└'
UpLightAndRightHeavy\u{2515}: '┕'
UpHeavyAndRightLight\u{2516}: '┖'
HeavyUpAndRight\u{2517}: '┗'
LightUpAndLeft\u{2518}: '┘'
UpLightAndLeftHeavy\u{2519}: '┙'
UpHeavyAndLeftLight\u{251a}: '┚'
HeavyUpAndLeft\u{251b}: '┛'
LightVerticalAndRight\u{251c}: '├'
VerticalLightAndRightHeavy\u{251d}: '┝'
UpHeavyAndRightDownLight\u{251e}: '┞'
DownHeavyAndRightUpLight\u{251f}: '┟'
VerticalHeavyAndRightLight\u{2520}: '┠'
DownLightAndRightUpHeavy\u{2521}: '┡'
UpLightAndRightDownHeavy\u{2522}: '┢'
HeavyVerticalAndRight\u{2523}: '┣'
LightVerticalAndLeft\u{2524}: '┤'
VerticalLightAndLeftHeavy\u{2525}: '┥'
UpHeavyAndLeftDownLight\u{2526}: '┦'
DownHeavyAndLeftUpLight\u{2527}: '┧'
VerticalHeavyAndLeftLight\u{2528}: '┨'
DownLightAndLeftUpHeavy\u{2529}: '┩'
UpLightAndLeftDownHeavy\u{252a}: '┪'
HeavyVerticalAndLeft\u{252b}: '┫'
LightDownAndHorizontal\u{252c}: '┬'
LeftHeavyAndRightDownLight\u{252d}: '┭'
RightHeavyAndLeftDownLight\u{252e}: '┮'
DownLightAndHorizontalHeavy\u{252f}: '┯'
DownHeavyAndHorizontalLight\u{2530}: '┰'
RightLightAndLeftDownHeavy\u{2531}: '┱'
LeftLightAndRightDownHeavy\u{2532}: '┲'
HeavyDownAndHorizontal\u{2533}: '┳'
LightUpAndHorizontal\u{2534}: '┴'
LeftHeavyAndRightUpLight\u{2535}: '┵'
RightHeavyAndLeftUpLight\u{2536}: '┶'
UpLightAndHorizontalHeavy\u{2537}: '┷'
UpHeavyAndHorizontalLight\u{2538}: '┸'
RightLightAndLeftUpHeavy\u{2539}: '┹'
LeftLightAndRightUpHeavy\u{253a}: '┺'
HeavyUpAndHorizontal\u{253b}: '┻'
LightVerticalAndHorizontal\u{253c}: '┼'
LeftHeavyAndRightVerticalLight\u{253d}: '┽'
RightHeavyAndLeftVerticalLight\u{253e}: '┾'
VerticalLightAndHorizontalHeavy\u{253f}: '┿'
UpHeavyAndDownHorizontalLight\u{2540}: '╀'
DownHeavyAndUpHorizontalLight\u{2541}: '╁'
VerticalHeavyAndHorizontalLight\u{2542}: '╂'
LeftUpHeavyAndRightDownLight\u{2543}: '╃'
RightUpHeavyAndLeftDownLight\u{2544}: '╄'
LeftDownHeavyAndRightUpLight\u{2545}: '╅'
RightDownHeavyAndLeftUpLight\u{2546}: '╆'
DownLightAndUpHorizontalHeavy\u{2547}: '╇'
UpLightAndDownHorizontalHeavy\u{2548}: '╈'
RightLightAndLeftVerticalHeavy\u{2549}: '╉'
LeftLightAndRightVerticalHeavy\u{254a}: '╊'
HeavyVerticalAndHorizontal\u{254b}: '╋'
LightDoubleDashHorizontal\u{254c}: '╌'
HeavyDoubleDashHorizontal\u{254d}: '╍'
LightDoubleDashVertical\u{254e}: '╎'
HeavyDoubleDashVertical\u{254f}: '╏'
DoubleHorizontal\u{2550}: '═'
DoubleVertical\u{2551}: '║'
DownSingleAndRightDouble\u{2552}: '╒'
DownDoubleAndRightSingle\u{2553}: '╓'
DoubleDownAndRight\u{2554}: '╔'
DownSingleAndLeftDouble\u{2555}: '╕'
DownDoubleAndLeftSingle\u{2556}: '╖'
DoubleDownAndLeft\u{2557}: '╗'
UpSingleAndRightDouble\u{2558}: '╘'
UpDoubleAndRightSingle\u{2559}: '╙'
DoubleUpAndRight\u{255a}: '╚'
UpSingleAndLeftDouble\u{255b}: '╛'
UpDoubleAndLeftSingle\u{255c}: '╜'
DoubleUpAndLeft\u{255d}: '╝'
VerticalSingleAndRightDouble\u{255e}: '╞'
VerticalDoubleAndRightSingle\u{255f}: '╟'
DoubleVerticalAndRight\u{2560}: '╠'
VerticalSingleAndLeftDouble\u{2561}: '╡'
VerticalDoubleAndLeftSingle\u{2562}: '╢'
DoubleVerticalAndLeft\u{2563}: '╣'
DownSingleAndHorizontalDouble\u{2564}: '╤'
DownDoubleAndHorizontalSingle\u{2565}: '╥'
DoubleDownAndHorizontal\u{2566}: '╦'
UpSingleAndHorizontalDouble\u{2567}: '╧'
UpDoubleAndHorizontalSingle\u{2568}: '╨'
DoubleUpAndHorizontal\u{2569}: '╩'
VerticalSingleAndHorizontalDouble\u{256a}: '╪'
VerticalDoubleAndHorizontalSingle\u{256b}: '╫'
DoubleVerticalAndHorizontal\u{256c}: '╬'
LightArcDownAndRight\u{256d}: '╭'
LightArcDownAndLeft\u{256e}: '╮'
LightArcUpAndLeft\u{256f}: '╯'
LightArcUpAndRight\u{2570}: '╰'
LightDiagonalUpperRightToLowerLeft\u{2571}: '╱'
LightDiagonalUpperLeftToLowerRight\u{2572}: '╲'
LightDiagonalCross\u{2573}: '╳'
LightLeft\u{2574}: '╴'
LightUp\u{2575}: '╵'
LightRight\u{2576}: '╶'
LightDown\u{2577}: '╷'
HeavyLeft\u{2578}: '╸'
HeavyUp\u{2579}: '╹'
HeavyRight\u{257a}: '╺'
HeavyDown\u{257b}: '╻'
LightLeftAndHeavyRight\u{257c}: '╼'
LightUpAndHeavyDown\u{257d}: '╽'
HeavyLeftAndLightRight\u{257e}: '╾'
Methods
impl BoxDrawing[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case